@@ -34,11 +34,17 @@ def get_data(data='validated_breath_data'):
         url='https://drive.google.com/uc?id=' + url.split('/')[-2]
 
 
-    elif data == 'repeat experiment':
+    elif data == 'repeat_experiment':
         url = 'https://drive.google.com/file/d/1r83aSt_LJ-nGVLXohFKbk8oUlGwtJ4Gi/view?usp=sharing'
         url='https://drive.google.com/uc?id=' + url.split('/')[-2]
 
 
+
+    elif data == 'handheld_data':
+        url = 'https://drive.google.com/file/d/1YZ6PDQpT9QkeVBLuRK6hThgaI54av6sf/view?usp=sharing'
+        url='https://drive.google.com/uc?id=' + url.split('/')[-2]
+
+
     else:
         return 'Data not available'
 
