@@ -18,21 +18,6 @@ SENSOR_FEATURES = ['sensor_1','sensor_2','sensor_3','sensor_4','sensor_5',
 
 
 
-# def find_header_value(field, filename):
-  
-  
-#     # Get first 6 lines
-#     with open(filename) as f:
-#         for line_no, line in enumerate(f):    
-#             if line.startswith(field):
-#                 # Get the part of the string after the field name
-#                 end_of_string = line[len(field):]
-#                 string = end_of_string[:-1]
-#                 break
-#         return string, line_no
-
-
-
 def find_header_value(field, filename):
   
   
@@ -91,13 +76,12 @@ def rename_columns(df):
 def get_label(f):   
 
     filename = f.split('/')[-1]
+    exp_name, _ = find_header_value('Name of the experiment =', f)
 
-    if ("Neg" in filename) or ("Control" in filename) or ('CONTROL' in filename):
+    if ("Neg" in filename) or ("Control" in filename) or ('CONTROL' in filename) or ("Neg" in exp_name) or ("Control" in exp_name) or ('CONTROL' in exp_name) or ("Neg" in filename):
         return "Control"
-    elif ("Pos" in filename) or ("Covid" in filename) or ('COVID' in filename):
+    elif ("Pos" in filename) or ("Covid" in filename) or ('COVID' in filename) or ("Pos" in exp_name) or ("Covid" in exp_name) or ('COVID' in exp_name) or ("Pos" in filename):
         return "Covid"
-    elif (exp_name[-2].islower()):
-        return "Control"
     else:
         return "Other"
 
@@ -153,7 +137,7 @@ def offset_batch_samples(df, sec=2, id_col='exp_unique_id'):
     """
     samples = df.groupby(id_col)
     df_list = []
-    for i, sample in groups:
+    for i, sample in samples:
         df_list.append(offset_one_sample(sample, sec=sec))
     return pd.concat(df_list)
 
@@ -226,7 +210,13 @@ def preprocess_single_file(f, parse_time=True, parse_filename=True, rename_colum
 
     return df_temp
 
-
+def get_all_files(parent_dir):
+    all_files = []
+    for path, subdirs, files in os.walk(parent_dir):
+        for name in files:
+            if (name.endswith('txt')) and (len(name) > 25) and ('Wash' not in name):
+                all_files.append(os.path.join(path, name))
+    return all_files
 
 def get_unique_files(df):
     """select one (chosen at random) of repeat experiemnts
@@ -260,7 +250,7 @@ def reorder_columns(df):
 
   return df
 
-def preprocess_all_files(path_to_measurements='', file_list=[], parse_time=True, parse_filename=True, concat_files=True, rename_column=True, no_repeat=False, fillna=True, offset=False, has_label=True):
+def preprocess_all_files(path_to_measurements, parse_time=True, parse_filename=True, concat_files=True, rename_column=True, no_repeat=False, fillna=True, offset=False, has_label=True):
     """preprocess all cycle (all txt file) of experiment
 
     Args:
@@ -278,11 +268,14 @@ def preprocess_all_files(path_to_measurements='', file_list=[], parse_time=True,
     """
 
 
-    if path_to_measurements:
-        list_files = glob.glob(os.path.join(path_to_measurements,"*.txt"))
-    else:
-        list_files = file_list
+    # if path_to_measurements:
+    #     list_files = glob.glob(os.path.join(path_to_measurements,"*.txt"))
+    # else:
+    #     list_files = file_list
 
+    list_files = get_all_files(path_to_measurements)
+    # print('len of files: ', len(list_files))
+    # print(list_files)
 
     df_list = []
     for i, f in enumerate(list_files):
