@@ -2,6 +2,7 @@
 import optuna
 import argparse
 import joblib
+import tempfile
 import pandas as pd
 from sklearn import linear_model
 from sklearn import datasets
@@ -149,7 +150,10 @@ def get_train_features(df, sensor='12', stage='pause', use_average = False):
         return data, sensors_to_use, stages_to_use
 
 
-        
+def log_arifact(filepath):
+    with tempfile.TemporaryDirectory() as tmp:
+        path = os.path.join(tmp, filepath)
+        mlflow.log_artifact(path)        
 
 def get_plots(model):
 
@@ -157,11 +161,14 @@ def get_plots(model):
 
     plot_model(model, plot = 'confusion_matrix', save=True)
     cm = os.path.join(os.getcwd(), 'Confusion Matrix.png')
-    mlflow.log_artifact(cm)
+    # mlflow.log_artifact(cm)
+    log_artifact(cm)
 
     plot_model(model, plot = 'class_report', save=True) 
     cr = os.path.join(os.getcwd(), 'Class Report.png')
-    mlflow.log_artifact(cr)      
+    # mlflow.log_artifact(cr)  
+    log_artifact(cr)
+    
 
 
     if 'predict_proba' in model_attributes:
@@ -333,9 +340,11 @@ def train_experiments(df, study_name='raptor', direction='maximize', stage='paus
         "http://ec2-3-10-175-206.eu-west-2.compute.amazonaws.com:5000/"
         )
     else:
-        # mlflow.set_tracking_uri("http://localhost:5000")
-        uri = os.path.join(os.getcwd(), "sqlite:///mlruns.db")
-        mlflow.set_tracking_uri(uri)
+        mlflow.set_tracking_uri("http://localhost:5000")
+    #     uri = os.path.join(os.getcwd(), "sqlite:///mlruns.db")
+    #     mlflow.set_tracking_uri(uri)
+
+
     # Initialize client
     # client = MlflowClient()
 
